/*
 * Sonar, open source software quality management tool.
 * Copyright (C) 2009 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.commons.database;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.Properties;

import org.apache.commons.configuration.Configuration;
import org.apache.commons.lang.StringUtils;

public class DriverDatabaseConnector extends AbstractDatabaseConnector {

  public DriverDatabaseConnector(Configuration configuration) {
    super(configuration, true);
  }

  public String getDriver() {
    return getConfiguration().getString(DatabaseProperties.PROP_DRIVER);
  }

  public String getUrl() {
    return getConfiguration().getString(DatabaseProperties.PROP_URL);
  }

  public String getUsername() {
    return getConfiguration().getString(DatabaseProperties.PROP_USER);
  }

  public String getPassword() {
    return getConfiguration().getString(DatabaseProperties.PROP_PASSWORD);
  }

  public Connection getConnection() throws SQLException {
    try {
      Class.forName(getDriver());
    } catch (ClassNotFoundException e) {
      SQLException ex = new SQLException("SQL driver not found " + getDriver());
      ex.initCause(e);
      throw ex;
    }
    return DriverManager.getConnection(getUrl(), getUsername(), getPassword());
  }
  
  public void setupEntityManagerFactory(Properties factoryProps) {
    factoryProps.put("hibernate.connection.url", getUrl());
    factoryProps.put("hibernate.connection.driver_class", getDriver());
    factoryProps.put("hibernate.connection.username", getUsername());
    if (StringUtils.isNotEmpty(getPassword())) {
      factoryProps.put("hibernate.connection.password", getPassword());
    }
  }
}